@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001, 2002 Marius Aamodt Eriksen <marius@monkey.org>
  * 
- * $Id: net.h,v 1.6 2003/06/08 05:56:47 marius Exp $
+ * $Id: net.h,v 1.6.2.1 2006/08/19 22:51:38 marius Exp $
  */
 
 #ifndef NET_H
@@ -14,6 +14,10 @@
 #define NET_SUPPORT_SOCKS4 0x01
 #define NET_SUPPORT_SOCKS5 0x02
 
+/* Return codes from negotation routines. */
+#define NET_FAIL -1		/* Negotiation failed */
+#define NET_NOPROXY -2		/* Negotiation succeeded - but don't proxy. */
+
 struct conndesc {
 	struct addrinfo *mirror_ai;
 	struct addrinfo *bind_ai;
